Documentation
¶
Overview ¶
Package sztestlog provides convenience functions to return a sztest.Chk object while setting the szlog package to the desired settings based on passed arguments for testing. If no Arguments are passed then both verbose and log levels are set to their maximums.
## Dedication
This project is dedicated to Reem. Your brilliance, courage, and quiet strength continue to inspire me. Every line is written in gratitude for the light and hope you brought into my life.
NOTE: Documentation reviewed and polished with the assistance of ChatGPT from OpenAI.
Index ¶
- func CaptureLog(t *testing.T, szlogArgs ...string) *sztest.Chk
- func CaptureLogAndStderr(t *testing.T, szlogArgs ...string) *sztest.Chk
- func CaptureLogAndStderrAndStdout(t *testing.T, szlogArgs ...string) *sztest.Chk
- func CaptureLogAndStdout(t *testing.T, szlogArgs ...string) *sztest.Chk
- func CaptureLogWithStderr(t *testing.T, szlogArgs ...string) *sztest.Chk
- func CaptureLogWithStderrAndStdout(t *testing.T, szlogArgs ...string) *sztest.Chk
- func CaptureNothing(t *testing.T, szlogArgs ...string) *sztest.Chk
- func CaptureStderr(t *testing.T, szlogArgs ...string) *sztest.Chk
- func CaptureStderrAndStdout(t *testing.T, szlogArgs ...string) *sztest.Chk
- func CaptureStdout(t *testing.T, szlogArgs ...string) *sztest.Chk
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CaptureLog ¶
CaptureLog returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.
func CaptureLogAndStderr ¶
CaptureLogAndStderr returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.
func CaptureLogAndStderrAndStdout ¶
CaptureLogAndStderrAndStdout returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.
func CaptureLogAndStdout ¶
CaptureLogAndStdout returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.
func CaptureLogWithStderr ¶
CaptureLogWithStderr returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.
func CaptureLogWithStderrAndStdout ¶
CaptureLogWithStderrAndStdout returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.
func CaptureNothing ¶
CaptureNothing returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.
func CaptureStderr ¶
CaptureStderr returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.
func CaptureStderrAndStdout ¶
CaptureStderrAndStdout returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.
Types ¶
This section is empty.