sztestlog

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 26, 2026 License: GPL-3.0 Imports: 3 Imported by: 0

README

Package sztestlog

package sztestlog

Package sztestlog provides convenience functions to return a sztest.Chk object while setting the szlog package to the desired settings based on passed arguments for testing. If no Arguments are passed then both verbose and log levels are set to their maximums.

Dedication

This project is dedicated to Reem. Your brilliance, courage, and quiet strength continue to inspire me. Every line is written in gratitude for the light and hope you brought into my life.

NOTE: Documentation reviewed and polished with the assistance of ChatGPT from OpenAI.

Documentation

Overview

Package sztestlog provides convenience functions to return a sztest.Chk object while setting the szlog package to the desired settings based on passed arguments for testing. If no Arguments are passed then both verbose and log levels are set to their maximums.

## Dedication

This project is dedicated to Reem. Your brilliance, courage, and quiet strength continue to inspire me. Every line is written in gratitude for the light and hope you brought into my life.

NOTE: Documentation reviewed and polished with the assistance of ChatGPT from OpenAI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CaptureLog

func CaptureLog(t *testing.T, szlogArgs ...string) *sztest.Chk

CaptureLog returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.

func CaptureLogAndStderr

func CaptureLogAndStderr(t *testing.T, szlogArgs ...string) *sztest.Chk

CaptureLogAndStderr returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.

func CaptureLogAndStderrAndStdout

func CaptureLogAndStderrAndStdout(
	t *testing.T, szlogArgs ...string,
) *sztest.Chk

CaptureLogAndStderrAndStdout returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.

func CaptureLogAndStdout

func CaptureLogAndStdout(t *testing.T, szlogArgs ...string) *sztest.Chk

CaptureLogAndStdout returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.

func CaptureLogWithStderr

func CaptureLogWithStderr(t *testing.T, szlogArgs ...string) *sztest.Chk

CaptureLogWithStderr returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.

func CaptureLogWithStderrAndStdout

func CaptureLogWithStderrAndStdout(
	t *testing.T, szlogArgs ...string,
) *sztest.Chk

CaptureLogWithStderrAndStdout returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.

func CaptureNothing

func CaptureNothing(t *testing.T, szlogArgs ...string) *sztest.Chk

CaptureNothing returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.

func CaptureStderr

func CaptureStderr(t *testing.T, szlogArgs ...string) *sztest.Chk

CaptureStderr returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.

func CaptureStderrAndStdout

func CaptureStderrAndStdout(t *testing.T, szlogArgs ...string) *sztest.Chk

CaptureStderrAndStdout returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.

func CaptureStdout

func CaptureStdout(t *testing.T, szlogArgs ...string) *sztest.Chk

CaptureStdout returns a new *sztest.Chk reference while setting the szlog logging level in a single call. If no szlogArgs are provided then szlog defaults to szlog.LevelAll and maximum verbosity.

Types

This section is empty.

Jump to