sztestlog

package module
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 16, 2025 License: GPL-3.0 Imports: 3 Imported by: 0

README

Package sztestlog

package sztestlog

Package sztestlog provides convenience functions to return a sztest.Chk object while setting the szlog package to the desired log level for testing.

Documentation

Overview

Package sztestlog provides convenience functions to return a sztest.Chk object while setting the szlog package to the desired log level for testing.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CaptureAll

func CaptureAll(
	t *testing.T,
) *sztest.Chk

CaptureAll returns a new *sztest.Chk reference capturing log, stderr and stdout setting the logging level to LevelAll in a single call.

func CaptureLog

func CaptureLog(t *testing.T, ll szlog.LogLevel) *sztest.Chk

CaptureLog returns a new *sztest.Chk reference and setting the logging level in a single call.

func CaptureLogAndStderr

func CaptureLogAndStderr(t *testing.T, ll szlog.LogLevel) *sztest.Chk

CaptureLogAndStderr returns a new *sztest.Chk reference and setting the logging level in a single call.

func CaptureLogAndStderrAndStdout

func CaptureLogAndStderrAndStdout(
	t *testing.T, ll szlog.LogLevel,
) *sztest.Chk

CaptureLogAndStderrAndStdout returns a new *sztest.Chk reference and setting the logging level in a single call.

func CaptureLogAndStdout

func CaptureLogAndStdout(t *testing.T, ll szlog.LogLevel) *sztest.Chk

CaptureLogAndStdout returns a new *sztest.Chk reference and setting the logging level in a single call.

func CaptureLogWithStderr

func CaptureLogWithStderr(t *testing.T, ll szlog.LogLevel) *sztest.Chk

CaptureLogWithStderr returns a new *sztest.Chk reference and setting the logging level in a single call.

func CaptureLogWithStderrAndStdout

func CaptureLogWithStderrAndStdout(
	t *testing.T, ll szlog.LogLevel,
) *sztest.Chk

CaptureLogWithStderrAndStdout returns a new *sztest.Chk reference and setting the logging level in a single call.

func CaptureNothing

func CaptureNothing(t *testing.T, ll szlog.LogLevel) *sztest.Chk

CaptureNothing returns a new *sztest.Chk reference and setting the logging level in a single call.

func CaptureStderr

func CaptureStderr(t *testing.T, ll szlog.LogLevel) *sztest.Chk

CaptureStderr returns a new *sztest.Chk reference and setting the logging level in a single call.

func CaptureStderrAndStdout

func CaptureStderrAndStdout(t *testing.T, ll szlog.LogLevel) *sztest.Chk

CaptureStderrAndStdout returns a new *sztest.Chk reference and setting the logging level in a single call.

func CaptureStdout

func CaptureStdout(t *testing.T, ll szlog.LogLevel) *sztest.Chk

CaptureStdout returns a new *sztest.Chk reference and setting the logging level in a single call.

Types

This section is empty.

Jump to