Documentation
¶
Overview ¶
Package sztestlog provides convenience functions to return a sztest.Chk object while setting the szlog package to the desired log level for testing.
Index ¶
- func CaptureAll(t *testing.T) *sztest.Chk
- func CaptureLog(t *testing.T, ll szlog.LogLevel) *sztest.Chk
- func CaptureLogAndStderr(t *testing.T, ll szlog.LogLevel) *sztest.Chk
- func CaptureLogAndStderrAndStdout(t *testing.T, ll szlog.LogLevel) *sztest.Chk
- func CaptureLogAndStdout(t *testing.T, ll szlog.LogLevel) *sztest.Chk
- func CaptureLogWithStderr(t *testing.T, ll szlog.LogLevel) *sztest.Chk
- func CaptureLogWithStderrAndStdout(t *testing.T, ll szlog.LogLevel) *sztest.Chk
- func CaptureNothing(t *testing.T, ll szlog.LogLevel) *sztest.Chk
- func CaptureStderr(t *testing.T, ll szlog.LogLevel) *sztest.Chk
- func CaptureStderrAndStdout(t *testing.T, ll szlog.LogLevel) *sztest.Chk
- func CaptureStdout(t *testing.T, ll szlog.LogLevel) *sztest.Chk
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CaptureAll ¶
CaptureAll returns a new *sztest.Chk reference capturing log, stderr and stdout setting the logging level to LevelAll in a single call.
func CaptureLog ¶
CaptureLog returns a new *sztest.Chk reference and setting the logging level in a single call.
func CaptureLogAndStderr ¶
CaptureLogAndStderr returns a new *sztest.Chk reference and setting the logging level in a single call.
func CaptureLogAndStderrAndStdout ¶
CaptureLogAndStderrAndStdout returns a new *sztest.Chk reference and setting the logging level in a single call.
func CaptureLogAndStdout ¶
CaptureLogAndStdout returns a new *sztest.Chk reference and setting the logging level in a single call.
func CaptureLogWithStderr ¶
CaptureLogWithStderr returns a new *sztest.Chk reference and setting the logging level in a single call.
func CaptureLogWithStderrAndStdout ¶
CaptureLogWithStderrAndStdout returns a new *sztest.Chk reference and setting the logging level in a single call.
func CaptureNothing ¶
CaptureNothing returns a new *sztest.Chk reference and setting the logging level in a single call.
func CaptureStderr ¶
CaptureStderr returns a new *sztest.Chk reference and setting the logging level in a single call.
func CaptureStderrAndStdout ¶
CaptureStderrAndStdout returns a new *sztest.Chk reference and setting the logging level in a single call.
Types ¶
This section is empty.